MoexAlgo: Получение уникальных данных от MOEX 📈
==================================================

:Website: `Сайт с полной документацией по продукту Algopack <https://moexalgo.github.io/>`_

---------------------------------------------------------------------------

MoexAlgo предоставляет данные и аналитику по рынку акций Московской Биржи (MOEX).
Более 100 уникальных метрик!
С помощью Algopack можно получать:

    * Исторические данные - для тестирования торговых стратегий, проверки гипотез и бэктестов
    * Онлайн данные - для алгоритмической торговли

MoexAlgo предоставляет наборы данных
--------------------------------------

- ⏰📊 Real-time market data.

  1. 🕯️ ``Candles`` - свечи по тикеру за заданный период
  2. 📚 ``OrderBook`` - стакан по тикеру

- 🚀🕯️ Super Candles

  1. 💹 ``TradeStats`` - метрики, рассчитанные на потоке сделок: цены, объемы, соотношения покупок и продаж
  2. 📊 ``OrderStats`` - метрики, рассчитанные на потоке заявок: кол-во и объемы выставленных/снятых заявок
  3. 📈 ``OBStats`` - метрики, рассчитанные на стакане котировок: кол-во уровней цен, спреды, ликвидность и дисбаланс покупок/продаж

- 🎯 ``HI2`` - Индекс рыночной концентрации
- 💼 ``FUTOI`` - Открытые позиции по фьючерсным контрактам в разрезе физ. и юр. лиц

Также, можно получить справочную информацию по инструментам, свечи и прочую торговую статистику

Пример использования
--------------------

Быстрое знакомство с библиотекой moexalgo - `quick_start.ipynb <./../../../samples/quick_start.ipynb>`_

Получение данных с использованием API - `download_algopack_data.ipynb <./../../../samples/download_algopack_data.ipynb>`_

Пример авторизации - `auth.ipynb <./../../../samples/auth.ipynb>`_

Для работы с библиотекой необходимо авторизоваться на https://passport.moex.com

.. code:: python

    from moexalgo import session

    username = "<email>"
    password = "<password>"

    session.authorize(username, password)

Чтобы получить доступ к полному набору данных, необходимо оформить бесплатную подписку на `странице <https://www.moex.com/ru/analyticalproducts?futoi>`_

.. code:: python

    from moexalgo import Ticker

    # выбираем акции Сбера
    sber = Ticker('SBER')

    # получим дневные свечи с 2020 года
    sber.candles(start='2020-01-01', end='2023-11-01').head()

💻 Установка
---------

Установка с помощью ```pip```:

.. code:: bash

    pip install moexalgo

🔍 Requirements
------------
- `Python <https://www.python.org>`_ \>= 3.8+
- `Pandas <https://github.com/pydata/pandas>`_
- `Numpy <http://www.numpy.org>`_ \>= 1.15.0

🤝 Комьюнити 
----------
Самые важные новости ALGOPACK `Подписывайтесь <https://t.me/moex_algopack>`_

Добавляйтесь в телеграмм-чат `Algopack <https://t.me/moex_algopack>`_

❓ Вопросы?
--------

Библиотека MoexAlgo будет дополняться. Если есть пожелания, идеи, замечания, пишите на algopack@moex.com

📜 Licence
-------

Apache Software License